#ifndef _TSLIB_H_
#define _TSLIB_H_
/*
 *  tslib/src/tslib.h
 *
 *  Copyright (C) 2001 Russell King.
 *
 * This file is placed under the LGPL.
 *
 * $Id: tslib.h,v 1.3 2004/07/21 19:12:59 dlowder Exp $
 *
 * Touch screen library interface definitions.
 */
#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */
#include <stdarg.h>
#include <sys/time.h>

#ifdef WIN32
  #define TSIMPORT __declspec(dllimport)
  #define TSEXPORT __declspec(dllexport)
  #define TSLOCAL
#else
  #define TSIMPORT
  #ifdef GCC_HASCLASSVISIBILITY
    #define TSEXPORT __attribute__ ((visibility("default")))
    #define TSLOCAL __attribute__ ((visibility("hidden")))
  #else
    #define TSEXPORT
    #define TSLOCAL
  #endif
#endif

// Define TSAPI for DLL builds
#ifdef TSLIB
  #ifdef TSLIB_EXPORTS
    #define TSAPI TSEXPORT
  #else
    #define TSAPI TSIMPORT
  #endif // TSLIB_EXPORTS
#else
  #define TSAPI
#endif // TSLIB

TSEXPORT struct tsdev;

TSEXPORT struct ts_sample {
	int		x;
	int		y;
	unsigned int	pressure;
	struct timeval	tv;
};

/*
 * Close the touchscreen device, free all resources.
 */
TSEXPORT int ts_close(struct tsdev *);

/*
 * Configure the touchscreen device.
 */
TSEXPORT int ts_config(struct tsdev *);

/*
 * Change this hook to point to your custom error handling function.
 */
extern TSEXPORT int (*ts_error_fn)(const char *fmt, va_list ap);

/*
 * Returns the file descriptor in use for the touchscreen device.
 */
TSEXPORT int ts_fd(struct tsdev *);

/*
 * Load a filter/scaling module
 */
TSEXPORT int ts_load_module(struct tsdev *, const char *mod, const char *params);

/*
 * Open the touchscreen device.
 */
TSEXPORT struct tsdev *ts_open(const char *dev_name, int nonblock);

/*
 * Return a scaled touchscreen sample.
 */
TSEXPORT int ts_read(struct tsdev *, struct ts_sample *, int);

/*
 * Returns a raw, unscaled sample from the touchscreen.
 */
TSEXPORT int ts_read_raw(struct tsdev *, struct ts_sample *, int);

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* _TSLIB_H_ */
